@@ -1,9 +1,9 @@
 
 qgraph.sem=function(
 	res,
-	layout="tree",
-	vsize.man=4,
-	vsize.lat=7,
+	layout="circle",
+	vsize.man=3,
+	vsize.lat=6,
 	filename="qgraph",
 	filetype="pdf",
 	residuals=TRUE,
@@ -11,10 +11,10 @@ qgraph.sem=function(
 	include=1:12,
 	latres=TRUE,
 	curve=0.2,
-	rotation=c(0,0,0,0),
+	residSize=0.2,
 	onefile=TRUE,
-	width=5,
-	height=5,
+	width=10,
+	height=10,
 	...)
 {
 require('sem')
@@ -150,7 +150,7 @@ V$labels[V$isresidual]=""
 
 # Create layout:
 l=layout
-if (layout=='tree' | layout=="springtree") 
+if (layout=='tree' | layout=="springtree" | layout=="circle") 
 {
 	if (residuals) 
 	{
@@ -201,8 +201,8 @@ if (layout=='tree' | layout=="springtree")
 	{
 
 		l=matrix(0,nrow=nrow(V),ncol=2)
-		l[V$type=='man',2]=-1
-		l[V$type=='lat',2]=1
+		l[V$type=='man',2]=-0.5
+		l[V$type=='lat',2]=0.5
 
 		sum=sum(V$type=='man')
 		l[V$type=='man',1]=seq(-1,1,length=sum+2)[2:(sum+1)]
@@ -233,23 +233,28 @@ if (layout=='tree' | layout=="springtree")
 
 if (layout=='circle' | layout=='circulair') 
 {
-	l=matrix(0,nrow=nrow(V),ncol=2)
+	l2 <- l
+	
+	E$curved <- 0
 
-	tl=sum(V$isresidual & V$type=='man')+1
-	l[V$isresidual & V$type=='man',1]=5*sin(seq(rotation[1],rotation[1]+2*pi, length=tl))[-tl]
-	l[V$isresidual & V$type=='man',2]=5*cos(seq(rotation[1],rotation[1]+2*pi, length=tl))[-tl]
+	tl=sum(l[,2] == -0.5)+1
+	l2[l[,2] == -0.5,1]=sin(seq(0,2*pi, length=tl))[-tl]
+	l2[l[,2] == -0.5,2]=cos(seq(0,2*pi, length=tl))[-tl]
+	
+	tl=sum(l[,2] == 0.5)+1
+	l2[l[,2] == 0.5,1]=0.5*sin(seq(0,2*pi, length=tl)+(pi/(tl-1)))[-tl]
+	l2[l[,2] == 0.5,2]=0.5*cos(seq(0,2*pi, length=tl)+(pi/(tl-1)))[-tl]
 
-	tl=sum(!V$isresidual & V$type=='man')+1
-	l[!V$isresidual & V$type=='man',1]=4*sin(seq(rotation[2],rotation[2]+2*pi, length=tl))[-tl]
-	l[!V$isresidual & V$type=='man',2]=4*cos(seq(rotation[2],rotation[2]+2*pi, length=tl))[-tl]
-
-	tl=sum(!V$isresidual & V$type=='lat')+1
-	l[!V$isresidual & V$type=='lat',1]=2*sin(seq(rotation[3],rotation[3]+2*pi, length=tl))[-tl]
-	l[!V$isresidual & V$type=='lat',2]=2*cos(seq(rotation[3],rotation[3]+2*pi, length=tl))[-tl]
-
-	tl=sum(V$isresidual & V$type=='lat')+1
-	l[V$isresidual & V$type=='lat',1]=1*sin(seq(rotation[4],rotation[4]+2*pi, length=tl))[-tl]
-	l[V$isresidual & V$type=='lat',2]=1*cos(seq(rotation[4],rotation[4]+2*pi, length=tl))[-tl]
+	if (residuals)
+	{
+		srt <- sort(l[l[,2] == -1,1],index.return=TRUE)$ix
+		l2[which(l[,2]==-1)[srt],] <- (1+residSize) * l2[l[,2] == -0.5,]
+		
+		srt <- sort(l[l[,2] == 1,1],index.return=TRUE)$ix
+		l2[which(l[,2] == 1)[srt],] <-  (1-2*residSize) * l2[l[,2] == 0.5,]
+	}
+	
+	l <- l2
 }
 
 #Set shapes
@@ -269,10 +274,8 @@ V$size[V$labels %in% colnames(res$S)]=vsize.man
 if (residuals) V$size[V$isresidual]=1
 
 # Make edgelist:
-edgelist=E[,1:2]
-for (i in 1:nrow(V)) edgelist[edgelist==V$ID[i]]=i
-edgelist$from=as.numeric(edgelist$from)
-edgelist$to=as.numeric(edgelist$to)
+
+edgelist <- apply(E[,1:2],2,match,V$ID)
 
 edgelist=as.matrix(edgelist)
 
@@ -316,6 +319,7 @@ Q=qgraph(
 	width=width,
 	height=height,
 	DoNotPlot=DNPL,
+	groups=NULL,
 	...)
 if (2%in%include) title("Specified model",line=-1)
 
@@ -340,6 +344,7 @@ qgraph(
 	width=width,
 	height=height,
 	diag=diag,
+	groups=NULL,
 	...)
 title("Unstandardized model",line=-1)
 }
@@ -376,6 +381,7 @@ qgraph(
 	width=width,
 	height=height,
 	diag=diag,
+	groups=NULL,
 	...)
 title("Standardized model",line=-1)
 }
@@ -399,6 +405,7 @@ qgraph(
 	width=width,
 	height=height,
 	diag=diag,
+	groups=NULL,
 	...)
 title("Unstandardized model",line=-1)
 }
@@ -420,6 +427,7 @@ qgraph(
 	width=width,
 	height=height,
 	diag=diag,
+	groups=NULL,
 	...)
 title("Standardized model",line=-1)
 }
@@ -504,4 +512,5 @@ if (filetype=="pdf")
 dev.off()
 print(paste("Output stored in ",getwd(),"/",output,sep=""))
 }
-}
\ No newline at end of file
+}
+
